@@ -288,12 +288,18 @@ class __Response__(Docs):
 		#
 
 	# system functions.
-	def __log_to_file__(self, message):
+	def log_to_file(self, message, raw=False):
 
 		# init.
 		try:
+			while True:
+				if len(message) > 0 and message[len(message)-1] == "\n": message = message[:-1]
+				else: break
 			with open(self.log_file, "a") as file:
-				file.write(f'{Date().seconds_timestamp} - {message}\n')
+				if raw:
+					file.write(f'{message}\n')
+				else:
+					file.write(f'{Date().seconds_timestamp} - {message}\n')
 			response = self.response()
 			response["success"] = True
 			response["message"] = "Succesfully logged the message."
@@ -311,6 +317,27 @@ class __Response__(Docs):
 			return response
 			
 		#
+	def __log_to_file__(self, message, raw=False):
+		self.log("Depricated, Response.__log_to_file__ has moved to Response.log_to_file", mode="alert")
+		return self.log_to_file(message, raw=raw)
+		#
+	def __serialize__(self, variable):
+		if isinstance(variable, (dict,Dictionary)):
+			new = {}
+			for key,value in variable.items():
+				new[key] = self.__serialize__(value)
+			variable = new
+		elif variable in [None, "None", "none", "null"]: variable = None
+		elif variable in [True, "True", "true", "TRUE"]: variable = True
+		elif variable in [False, "False", "false", "FALSE"]: variable = False
+		elif isinstance(variable, (String,str)):
+			if "." in variable:
+				try: variable = float(variable)
+				except: a=1
+			else:
+				try: variable = int(variable)
+				except: a=1
+		return variable
 
 	#
 	
@@ -475,74 +502,62 @@ class ResponseObject(object):
 		#
 		# Should be initialized with Response.success or Response.error.
 		#
-		# the response attributes.
+		# the response attributes (dict or dict in str format).
 		attributes={
 			"success":False,
 			"message":None,
 			"error":None,
 		},
-		# import a dumped json response (str) (ignores attributes).
-		json=None,
 	):
 
 		# check self instance.
 		if isinstance(attributes, ResponseObject):
-			#attributes = attributes.dict()
-			#self = attributes
 			attributes = attributes.dict()
-		elif isinstance(json, ResponseObject):
-			json = json.dict()
-
-		# assign attributes.
-		if json != None:
-			if isinstance(json, str):
+		elif attributes.__class__.__name__ in ["OutputObject"]:
+			attributes = attributes.response()
+		elif isinstance(attributes, (str,String)):
 				try:
-					self.assign(pypi_json.loads(json))
+					self.assign(pypi_json.loads(attributes))
 				except:
 					try:
-						self.assign(ast.literal_eval(json))
+						self.assign(ast.literal_eval(attributes))
 					except:
-						self.assign(pypi_json.loads(String(json).slice_dict()))
-			elif isinstance(json, dict):
-				self.assign(json)
-			elif json != None:
-				raise Exceptions.InvalidUsage("The ResponseObject.json parameter must be str / dict format.")
-		else:
+						self.assign(pypi_json.loads(String(attributes).slice_dict()))
+		elif isinstance(attributes, (dict,Dictionary)):
 			self.assign(attributes)
+		else:
+			raise Exceptions.InvalidUsage(f"<ResponseObject.attributes>: parameter [attributes] must be a [dict, dict in str format], not [{attributes.__class__.__name__}].")
 
 		# clean message & error.
-		try:
-			if self.message in ["None", "null", "", "nan"]: self.message = None
-			if self.message != None:
-				self.message = String(self.message).capitalized_word()
-			if self.error in ["None", "null", "", "nan"]: self.error = None
-			if self.error != None:
-				self.error = String(self.error).capitalized_word()
-			while True:
-				if self.message != None and len(self.message) >= 1 and self.message[len(self.message)-1] in [" ", ".", ","]:
-					self.message = self.message[:-1]
-				elif self.error != None and len(self.error) >= 1 and self.error[len(self.error)-1] in [" ", ".", ","]:
-					self.error = self.error[:-1]
-				elif self.error != None and len(self.error) >= len("Error: ") and self.error[:len("Error: ")] in ["Error: "]:
-					self.error = String(self.error[len("Error: "):]).capitalized_word()
-				else: break
-			
-			# add dot.
-			if self.message != None  and len(self.message) > 0 and self.message[len(self.message)-1] not in ["!", "?"]:
-				self.message += "."
-			if self.error != None  and len(self.error) > 0 and self.error[len(self.error)-1] not in ["!", "?"]:
-				self.error += "."
-
-			# check error passed as success response. & reversed
-			if self.message != None and len(self.message) >= len("Failed") and self.message[:len("Failed")] == "Failed":
-				#_traceback_.print_exc() 
-				raise ValueError("A success response may not start with (failed ...). You most likely called an Response.success return while you meant Response.error.")
-			if self.error != None and len(self.error) >= len("Success") and self.error[:len("Success")] == "Success":
-				#_traceback_.print_exc() 
-				raise ValueError("An error response may not start with (success ...). You most likely called an Response.error return while you meant Response.success.")
+		if self.message != None: self.message = String(self.message).capitalized_word()
+		if self.error != None: self.error = String(self.error).capitalized_word()
+		while True:
+			if self.message != None and len(self.message) >= 1 and self.message[len(self.message)-1] in [" ", ".", ","]:
+				self.message = self.message[:-1]
+			elif self.error != None and len(self.error) >= 1 and self.error[len(self.error)-1] in [" ", ".", ","]:
+				self.error = self.error[:-1]
+			elif self.error != None and len(self.error) >= len("Error: ") and self.error[:len("Error: ")] in ["Error: "]:
+				self.error = String(self.error[len("Error: "):]).capitalized_word()
+			elif self.error != None and len(self.error) >= len("..") and String(self.error).last("..") in [".."]:
+				self.error = str(String(self.error).remove_last("."))
+			else: break
 		
-		# except if not present.
-		except AttributeError: a=1
+		# add dot.
+		if self.message != None  and len(self.message) > 0 and self.message[len(self.message)-1] not in ["!", "?"]:
+			self.message += "."
+		if self.error != None  and len(self.error) > 0 and self.error[len(self.error)-1] not in ["!", "?"]:
+			self.error += "."
+
+
+		# check error passed as success response. & reversed
+		if self.message != None and len(self.message) >= len("Failed") and self.message[:len("Failed")] == "Failed":
+			#_traceback_.print_exc() 
+			raise ValueError("A success response may not start with (failed ...). You most likely called an Response.success return while you meant Response.error.")
+		if self.error != None and len(self.error) >= len("Success") and self.error[:len("Success")] == "Success":
+			#_traceback_.print_exc() 
+			raise ValueError("An error response may not start with (success ...). You most likely called an Response.error return while you meant Response.success.")
+		
+		#
 	# clean default values.
 	def clean(self, 
 		# the clean options, select * for all, options: [traceback].
@@ -577,11 +592,11 @@ class ResponseObject(object):
 	# assign dict.
 	def assign(self, dictionary):
 		if isinstance(dictionary, (dict, Dictionary)):
-			for key,value in dictionary.items():
+			for key,value in Response.__serialize__(dictionary).items():
 				self[key] = value
 		elif isinstance(dictionary, (tuple, list, Array)):
 			for key,value in dictionary:
-				self[key] = value
+				self[key] = Response.__serialize__(value)
 		else:
 			raise Exceptions.InvalidUsage("The dictionary parameter must be a dict or tuple.")
 		return self
